@@ -19,9 +19,12 @@ from urllib.parse import urljoin
 
 
 class TT_API:
-    def __init__(self, to_users=[]):
-        self._appid = 'health-data'
-        self._secret = '7c77496167924d4e9581d44c7dc8987a'
+    def __init__(self, to_users=[], from_user='health-algorithm'):
+        self._appid = from_user
+        self._secret = {
+            'health-algorithm': '223d0590a25a47cea1385197ad31ad81',
+            'health-data': '7c77496167924d4e9581d44c7dc8987a'
+        }[from_user]
         self._host = 'https://ttapi.myoas.com'
         self._headers = {
             "Content-Type": "application/x-www-form-urlencoded",
